Exception: Finlight::Error
- Inherits:
-
StandardError
- Object
- StandardError
- Finlight::Error
- Defined in:
- lib/finlight/errors.rb
Overview
Base class for all errors raised by this library.
Base class for all errors raised by this library.